/* jshint esnext:true */


//list of database fields for email template mail merge
function createFieldList(){
  var person = app.models.Person.fields._values .map(e => 'Person::' + e);
  var company = app.models.Company.fields._values .map(e => 'Company::' + e);
  var event = app.models.Event.fields._values .map(e => 'Event::' + e);

  return person.concat(company, event);
}


//helper function for uniqueValues
function onlyUnique(value, index, self) { 
    return self.indexOf(value) === index;
}


//removes duplicates from an array
function uniqueValues(array){
  return array.filter(onlyUnique);
}


//filters out duplicate people and returns last name, first name
function uniquePeople(people){
  var uniqueList = people.filter(onlyUnique);
  return uniqueList.map(e => (e && e.LastName ? e.LastName + ', ' : '') + (e && e.FirstName ? e.FirstName : ''));
}


//returns last name, first name
function personValueList(people){
  if(people !== null){
    return people.map(e => (e && e.LastName ? e.LastName + ', ' : '') + (e && e.FirstName ? e.FirstName : ''));
  }
    return [];
}


//returns sorted categories
function categoryRecordList(categories){
  categoriesFiltered = categories.filter(item => typeof item !== 'undefined');
  return categoriesFiltered.sort((a,b) => (a.Name || '').localeCompare(b.Name || ''));
}


//returns invitee counts grouped by event for the chart
//field = Invited, RSVP, or Attended
function groupByEvent(events, array, field){ 
  if(events === null || typeof events[0] === 'undefined'){
    return [];
  }

  var eventDict ={};
  events.forEach(e=> eventDict[e.Id] = (e.Name || ''));
  
  var inviteeDict = {};
  for(var i=0; i<events.length; i++){
    if(events[i].Invitee.length > 0){
      events[i].Invitee.forEach(e=> inviteeDict[events[i].Id] = (inviteeDict[events[i].Id] || 0) + e[field]);
    }else{
      inviteeDict[events[i].Id] = 0;
    }
  }
  return Object.keys(inviteeDict).sort((a, b) => (eventDict[a] < eventDict[b] ? -1 : (eventDict[a] > eventDict[b] ? 1 : 0))).map(key=>inviteeDict[key]);
}


function hourList(){
  return ['01','02','03','04','05','06','07','08','09','10','11','12'];
}


function minuteList(){
  return ['00','01','02','03','04','05','06','07','08','09',
          '10','11','12','13','14','15','16','17','18','19',
          '20','21','22','23','24','25','26','27','28','29',
          '30','31','32','33','34','35','36','37','38','39',
          '40','41','42','43','44','45','46','47','48','49',
          '50','51','52','53','54','55','56','57','58','59'];
}


function periodList(){
  return ['AM','PM'];
}


//prepares the time dropdowns for display
//data is stored in one timestamp field and must be parsed out into three data entry fields
function timeDisplay(event){
  
  var widgets = app.pages.EventDetail.descendants;
  
  if(event === null || event.StartTime === null){
    widgets.StartHour.value = null;
    widgets.StartMinute.value = null;
    widgets.StartPeriod.value = null;
  }else{
    var startHour = event.StartTime.getHours();    
    widgets.StartMinute.value = ('0' + event.StartTime.getMinutes().toString()).substr(-2);
    
    if(startHour >= 12){
      widgets.StartHour.value = ('0' + (startHour === 12 ? 12 : startHour - 12).toString()).substr(-2);
      widgets.StartPeriod.value = 'PM';
    }else{
      widgets.StartHour.value = ('0' + (startHour === 0 ? 12 : startHour).toString()).substr(-2);
      widgets.StartPeriod.value = 'AM';
    }
  }
  
  if(event === null || event.EndTime === null){
    widgets.EndHour.value = null;
    widgets.EndMinute.value = null;
    widgets.EndPeriod.value = null;
  }else{
    var endHour = event.EndTime.getHours();    
    widgets.EndMinute.value = ('0' + event.EndTime.getMinutes().toString()).substr(-2);
    
    if(endHour >= 12){
      widgets.EndHour.value = ('0' + (endHour === 12 ? 12 : endHour - 12).toString()).substr(-2);
      widgets.EndPeriod.value = 'PM';
    }else{
      widgets.EndHour.value = ('0' + (endHour === 0 ? 12 : endHour).toString()).substr(-2);
      widgets.EndPeriod.value = 'AM';
    }
  }
}




